==> zuora_sdk-3.1.0.7b0.tar.gz: zuora_sdk-3.1.0.7b0/setup.py <==
# coding: utf-8

"""
    Zuora API Reference

    REST API reference for the Zuora Billing, Payments, and Central Platform! Check out the [REST API Overview](https://www.zuora.com/developer/api-references/api/overview/).

    OpenAPI spec version: 2024-05-20
    Contact: docs@zuora.com

"""
import sys

from setuptools import setup, find_packages
import os


NAME = "zuora_sdk"
VERSION = os.getenv('ZUORA_SDK_VERSION', '0.0.0')  # Default to '0.0.0' if the environment variable is not set

# Only raise an error if VERSION is not set during packaging (sdist or bdist_wheel)

if VERSION == '0.0.0' and any(cmd in sys.argv for cmd in ('sdist', 'bdist_wheel')):
    raise ValueError("Environment variable ZUORA_SDK_VERSION is not set!")

PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Zuora API Reference",
    author="Zuora",
    author_email="docs@zuora.com",
    url="",
    keywords=["Zuora", "SDK"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description="""\
    REST API reference for the Zuora Billing, Payments, and Central Platform! Check out the [REST API Overview](https://www.zuora.com/developer/api-references/api/overview/).
    """,  # noqa: E501
    package_data={"zuora_sdk": ["py.typed"]},
)

==> zuora_sdk-3.1.0.8b0.tar.gz: zuora_sdk-3.1.0.8b0/setup.py <==
# coding: utf-8

"""
    Zuora API Reference

    REST API reference for the Zuora Billing, Payments, and Central Platform! Check out the [REST API Overview](https://www.zuora.com/developer/api-references/api/overview/).

    OpenAPI spec version: 2024-05-20
    Contact: docs@zuora.com

"""
import sys

from setuptools import setup, find_packages
import os


NAME = "zuora_sdk"
VERSION = os.getenv('ZUORA_SDK_VERSION', '0.0.0')  # Default to '0.0.0' if the environment variable is not set

# Only raise an error if VERSION is not set during packaging (sdist or bdist_wheel)

if VERSION == '0.0.0' and any(cmd in sys.argv for cmd in ('sdist', 'bdist_wheel')):
    raise ValueError("Environment variable ZUORA_SDK_VERSION is not set!")

PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Zuora API Reference",
    author="Zuora",
    author_email="docs@zuora.com",
    url="",
    keywords=["Zuora", "SDK"],
    install_requires=REQUIRES,
    packages=find_packages(where='.', exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description="""\
    REST API reference for the Zuora Billing, Payments, and Central Platform! Check out the [REST API Overview](https://www.zuora.com/developer/api-references/api/overview/).
    """,  # noqa: E501
    package_data={"zuora_sdk": ["py.typed"]},
)
